# Introduction

Scientific posters are often used to present research/information at conferences and other forms of meeting where they can facilitate presentation of your research for discussion with colleagues[^1]. This article explains the basics of typesetting a poster in LaTeX.

# Tikzposter 
Tikzposter is a document class used to generate scientific posters in PDF format. It uses the TikZ package and provides very flexible layouts.

## The preamble and the title

The preamble in a tikzposter class has the standard syntax:
```
\documentclass[25pt, a0paper, portrait]{tikzposter}
\title{Tikz Poster Example}
\author{Overleaf Team}
\date{\today}
\institute{Overleaf Institute}
\usetheme{Board}

\begin{document}

\maketitle

\end{document}
```

## The preamble

The first command, \documentclass[...]{tikzposter} declares that this document is a tikzposter. The additional parameters inside the brackets set the font size, the paper size and the orientation; respectively.

The available font sizes are: 12pt, 14pt, 17pt, 20pt and 25pt. The possible paper sizes are: a0paper, a1paper and a2paper. There are some additional options, see the further reading section for a link to the documentation.

The self-descriptive commands title, author, date and institute are used to set the author information.

The command \usetheme{Board} sets the current theme, i.e., changes the colours and the decoration around the text boxes. See the reference guide for screenshots of available themes.

The command \maketitle prints the title on top of the poster.

If you are keen to see a more detailed example you can open

## The body

The body of the poster is created by means of text blocks. Multi-column placement can be enabled and the width can be explicitly controlled for each column, this provides a lot of flexibility to customize the look of the final output.

```
\documentclass[25pt, a0paper, portrait]{tikzposter}

\title{Tikz Poster Example}
\author{Overleaf Team}
\date{\today}
\institute{Overleaf Institute}

\usepackage{blindtext}
\usepackage{comment}

\usetheme{Board}

\begin{document}

\maketitle

\block{~}
{
    \blindtext
}

\begin{columns}
    \column{0.4}
    \block{More text}{Text and more text}
    
    \column{0.6}
    \block{Something else}{Here, \blindtext \vspace{4cm}}
    \note[
        targetoffsetx=-9cm, 
        targetoffsety=-6.5cm, 
        width=0.5\linewidth
        ]
        {e-mail \texttt{welcome@overleaf.com}}
\end{columns}

\begin{columns}
    \column{0.5}
    \block{A figure}
    {
        \begin{tikzfigure}
            \includegraphics[width=0.4\textwidth]{images/overleaf-logo}
        \end{tikzfigure}
    }
    \column{0.5}
    \block{Description of the figure}{\blindtext}
\end{columns}

\end{document}
```
In a tikzposter document the text is organized in blocks, each block is created by the command \block{}{} which takes two parameters, each one inside a pair of braces. The first one is the title of the block and the second one is the actual text to be printed inside the block.

The environment columns enables multi-column text, the command \column{} starts a new column and takes as parameter the relative width of the column, 1 means the whole text area, 0.5 means half the text area and so on.

The command \note[]{} is used to add additional notes that are rendered overlapping the text block. Inside the brackets you can set some additional parameters to control the placement of the note, inside the braces the text of the note must be typed.

## Note on figure captions and references

As noted within the tikzposter documentation, the standard LATEX figure environment is not compatible with the tikzposter document class. Consequently, the LaTeX mechanism for adding captions and referencing figures must be used within the tikzfigure environment, like this:
```
\begin{tikzfigure}[Caption of the figure]
\label{fig:fig1}
Figure
\end{tikzfigure}
``



# My poster Example
# Preamble
```
\documentclass[25pt, a0paper, portrait]{tikzposter}
\usepackage[utf8]{inputenc}
\usepackage{authblk}
\usepackage{graphicx}
\usepackage{hyperref}
\renewcommand\refname{Referencias} 
\usetheme{Board}
```


# Code for large titles:
```
\makeatletter
\def\title#1{\gdef\@title{\scalebox{\TP@titletextscale}{%
\begin{minipage}[t]{\linewidth}
\centering
\Huge
#1
\par
\vspace{0.5em}
\end{minipage}%
}}}
\makeatother
```

# Code for several authors:

```
\makeatletter
\renewcommand\maketitle{\AB@maketitle} % revert \maketitle to its old definition
\renewcommand\AB@affilsepx{\quad\protect\Affilfont} % put affiliations into one line
\makeatother
\renewcommand\Affilfont{\Large} % set font for affiliations

% Frontmatter
\title{Título de mi Trabajo de Investigación para Presentar en un Poster de Divulgación Científica}
% Autores
\author[1]{Homer Jay Simpson}
\author[2]{Gerardo Marx Chávez-Campos}
\author[3]{Jean-Baptiste Joseph Fourier} 
\author[3]{Pierre Simon Laplace}
\affil[1]{Twenty Century Fox}
\affil[2]{Posgrado en Ciencias en Ingeniería Electrónica}
\affil[3]{École Normale Supérieure}
```

# Logos
```
\titlegraphic{
	\includegraphics[width=16cm,height=5cm]{sep-logo}\quad
	\includegraphics[width=12cm,height=5cm]{tecnm-logo.png}\quad
	\includegraphics[width=6cm,height=5cm]{itm-logo.png}\quad
	%\includegraphics[width=5cm,height=5cm]{ibq-logo.png}\quad
	\includegraphics[width=14cm,height=5cm]{pcie-logo.png}\quad
    %\includegraphics[width=14cm,height=5cm]{ooapas-logo.png}
	}
```

# References

```
\block{}{
\small %cambiar a \tiny si son muchas referencias
\bibliographystyle{ieeetr}
\bibliography{references.bib}
}
```

